@@ -15,10 +15,9 @@ import logging
 from functools import wraps
 from textwrap import indent
 
-from deprecation import deprecated
-
+from .directives import _document_directive
 from .environment import ComputeEnvironment
-from .version import __version__
+from .errors import FlowProjectDefinitionError
 
 logger = logging.getLogger(__name__)
 
@@ -44,8 +43,8 @@ def cmd(func):
         prefixes to the shell command provided here.
     """
     if getattr(func, "_flow_with_job", False):
-        raise RuntimeError(
-            "@cmd should appear below the @with_job decorator in your script"
+        raise FlowProjectDefinitionError(
+            "The @flow.cmd decorator must appear below the @flow.with_job decorator."
         )
     setattr(func, "_flow_cmd", True)
     return func
@@ -97,7 +96,9 @@ def with_job(func):
             return 'trap "cd `pwd`" EXIT && cd {} && echo "hello {job}"'.format(job.ws)
     """
     if getattr(func, "_flow_aggregate", False):
-        raise RuntimeError("The @with_job decorator cannot be used with aggregation.")
+        raise FlowProjectDefinitionError(
+            "The @with_job decorator cannot be used with aggregation."
+        )
 
     @wraps(func)
     def decorated(*jobs):
@@ -111,18 +112,16 @@ def with_job(func):
     return decorated
 
 
-@deprecated(
-    deprecated_in="0.15",
-    removed_in="1.0",
-    current_version=__version__,
-    details="Use FlowProject.operation.with_directives",
-)
 class directives:
     """Decorator for operation functions to provide additional execution directives.
 
     Directives can for example be used to provide information about required resources
     such as the number of processes required for execution of parallelized operations.
-    For more information, read about :ref:`signac-docs:directives`.
+    For more information, read about :ref:`signac-docs:cluster_submission_directives`.
+
+    .. deprecated:: 0.15
+        This decorator is deprecated and will be removed in 1.0.
+        Use :class:`FlowProject.operation.with_directives` instead.
 
     """
 
@@ -156,13 +155,7 @@ class directives:
         return func
 
 
-def _document_directive(directive):
-    name = directive._name
-    name = name.replace("_", r"\_")
-    doc = directive.__doc__
-    return f"**{name}**\n\n{doc}"
-
-
+# Remove when @flow.directives is removed
 _directives_to_document = (
     ComputeEnvironment._get_default_directives()._directive_definitions.values()
 )
